@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 //
-// Copyright (c) 2009-2014 Icinga Developer Team.
+// Copyright (c) 2009-2015 Icinga Developer Team.
 // All rights reserved.
 //
 // icinga-web is free software: you can redistribute it and/or modify
@@ -114,7 +114,7 @@ class Api_MacroExpanderModel extends IcingaApiBaseModel {
     private function appendHostData(IcingaHosts $host, array &$data) {
         $data['HOSTADDRESS']    = $host->address;
         $data['HOSTALIAS']      = $host->alias;
-        $data['DISPLAYNAME']    = $host->display_name;
+        $data['HOSTDISPLAYNAME']    = $host->display_name;
         $data['HOSTSTATEID']    = $host->status->current_state;
 
         $this->appendCustomVariables($host->customvariables, '_HOST', $data);
@@ -132,4 +132,4 @@ class Api_MacroExpanderModel extends IcingaApiBaseModel {
             $data[$prefix. strtoupper($variable->varname)] = $variable->varvalue;
         }
     }
-}
\ No newline at end of file
+}
