@@ -2,20 +2,20 @@
 // {{{ICINGA_LICENSE_CODE}}}
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
-// 
+//
 // Copyright (c) 2009-2015 Icinga Developer Team.
 // All rights reserved.
-// 
+//
 // icinga-web is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // icinga-web is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with icinga-web.  If not, see <http://www.gnu.org/licenses/>.
 // -----------------------------------------------------------------------------
@@ -147,7 +147,7 @@ class Api_Store_LegacyLayer_IcingaApiModel extends IcingaApiDataStoreModel imple
 
             $resultCols =  $this->getResultColumns();
             $data =  $this->execRead();
-            
+
             if ($this->isCount) {
                 $fields = $this->getFields();
                 $_data = array(array());
@@ -164,7 +164,7 @@ class Api_Store_LegacyLayer_IcingaApiModel extends IcingaApiDataStoreModel imple
                 }
                 $data = $_data;
             }
-            
+
             $this->result = $this->getContext()->getModel(
                                 "Store.LegacyLayer.LegacyApiResult","Api",array(
                                     "result" => $data,
@@ -203,13 +203,14 @@ class Api_Store_LegacyLayer_IcingaApiModel extends IcingaApiDataStoreModel imple
     /**
       * Validate if a matcher is valid
       *
-      * @param string  $matcher     matcher to validate (e.g. '=')
-      * @param boolean $raise_error raise an error when matcher is not valid
+      * @param  string  $matcher     Matcher to validate (e.g. '=')
+      * @param  bool    $raiseError  Whether throw an exception when the matcher is invalid
       *
-      * @return boolean
+      * @return bool
+      * @throws AppKitException      When the matcher is invalid and $raiseError is true
       */
-    public function validateMatcher($matcher, $raise_error=true) {
-        if (!is_array($this->validMatchers)) {
+    public function validateMatcher($matcher, $raiseError = true) {
+        if (! is_array($this->validMatchers)) {
             // retrieve matchers from the interface
             $refl = new ReflectionClass('IcingaApiConstants');
             $this->validMatchers = array();
@@ -220,12 +221,12 @@ class Api_Store_LegacyLayer_IcingaApiModel extends IcingaApiDataStoreModel imple
             }
         }
 
-        if (in_array($matcher, $this->validMatchers)) {
+        if (in_array(strtolower($matcher), $this->validMatchers)) {
             return true;
         } else {
-            if ($raise_error === true) {
+            if ((bool) $raiseError) {
                 throw new AppKitException(
-                    'validateMatcher(): invalid matcher used "%s"',
+                    'Invalid matcher used "%s"',
                     $matcher
                 );
             }
