@@ -2,20 +2,20 @@
 // {{{ICINGA_LICENSE_CODE}}}
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
-// 
-// Copyright (c) 2009-2014 Icinga Developer Team.
+//
+// Copyright (c) 2009-2015 Icinga Developer Team.
 // All rights reserved.
-// 
+//
 // icinga-web is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // icinga-web is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with icinga-web.  If not, see <http://www.gnu.org/licenses/>.
 // -----------------------------------------------------------------------------
@@ -23,10 +23,10 @@
 
 
 class API_Views_ApiDQLViewModel extends IcingaBaseModel {
-    private $dqlViews;
-    private $view;
-    private $viewParameters;
-    private $defaultConnection = "icinga";
+    private     $dqlViews;
+    protected   $view;
+    private     $viewParameters;
+    private     $defaultConnection = "icinga";
 
     /**
      *
@@ -48,8 +48,15 @@ class API_Views_ApiDQLViewModel extends IcingaBaseModel {
 
     private static $bufferedResults = array();
 
+    /**
+     * Resolved custom variable to select expression map
+     *
+     * @var array
+     */
+    protected $resolvedCustomVariables = array();
+
     public function getResultFromViewBuffer($viewName) {
-        
+
         if(isset(self::$bufferedResults[$viewName])) {
             return self::$bufferedResults[$viewName];
         }
@@ -80,17 +87,16 @@ class API_Views_ApiDQLViewModel extends IcingaBaseModel {
         $this->user = $this->getContext()->getUser()->getNsmUser();
 
         $this->parseBaseDQL();
+        $this->parseCustomVariables();
         $this->parseDQLExtensions();
         $this->parseDependencies();
-       
-
     }
 
     public function getResult() {
         AppKitLogger::verbose("Processing query %s ",$this->currentQuery->getSqlQuery());
 
         $result = $this->currentQuery->execute(null,Doctrine_Core::HYDRATE_SCALAR);
-        
+
         $normalizedResult = array();
         foreach($result as $row) {
             $normalizedRow = array();
@@ -154,9 +160,9 @@ class API_Views_ApiDQLViewModel extends IcingaBaseModel {
          $this->currentQuery->andWhere("$field $operator $value");
 
          AppKitLogger::verbose("Query after addWhere (%s %s %s) %s ",$field, $operator, $value, $this->currentQuery->getSqlQuery());
-         
+
     }
-   
+
     private function applyMerger(&$result) {
         foreach($this->mergeDependencies as $merger) {
             $view = $merger->getView();
@@ -172,7 +178,7 @@ class API_Views_ApiDQLViewModel extends IcingaBaseModel {
             throw new AgaviException("Target $target not found in views, check your template or create a view $target in views.xml");
         }
 
-        $this->view = $this->dqlViews[$this->view];        
+        $this->view = $this->dqlViews[$this->view];
     }
 
     private function parseBaseDQL() {
@@ -193,6 +199,63 @@ class API_Views_ApiDQLViewModel extends IcingaBaseModel {
 
     }
 
+    /**
+     * Append customvariables to query
+     */
+    private function parseCustomVariables() {
+        if (! empty($this->view['customvariables'])) {
+            foreach ($this->view['customvariables'] as $customvariable) {
+                $params = $customvariable['params'];
+                $variables = AppKitArrayUtil::trimSplit($params['list']);
+
+                if (! isset($params['leftJoin'])) {
+                    continue;
+                }
+
+                $leftJoin = $params['leftJoin'];
+                $prefix = 'cv_';
+
+                if (isset($params['prefix'])) {
+                    $prefix = $params['prefix'];
+                }
+
+                foreach ($variables as $variable) {
+                    $canonicalName = strtolower($variable);
+                    $safeName = $prefix . $canonicalName;
+
+                    $this->currentQuery->leftJoin(
+                        $leftJoin
+                        . ' AS '
+                        . $safeName
+                        . ' WITH '
+                        . $safeName
+                        . '.varname=?',
+                        $variable
+                    );
+
+                    $this->currentQuery->addSelect(
+                        $safeName . '.varvalue AS value'
+                    );
+
+                    $filterName = $canonicalName . '_value';
+
+                    $this->view['filter'][$filterName] = array(
+                        'name'  => $filterName,
+                        'type'  => 'dql',
+                        'calls' => array(
+                            array(
+                                'type'  => 'resolve',
+                                'arg'   => $safeName . '.varvalue'
+                            )
+                        )
+                    );
+
+                    $this->resolvedCustomVariables[$filterName] = $safeName . '.varvalue';
+                }
+            }
+        }
+    }
+
     private function createDQL($dql) {
         $query = IcingaDoctrine_Query::create();
         $query->setConnection($this->connection);
@@ -202,10 +265,10 @@ class API_Views_ApiDQLViewModel extends IcingaBaseModel {
         $this->applyCredentials($query);
         AppKitLogger::verbose("Query : %s", $query->getSqlQuery());
         $this->currentQuery = $query;
-        
+
     }
 
-    private function applyCredentials(IcingaDoctrine_Query &$query) {
+    protected function applyCredentials(IcingaDoctrine_Query &$query) {
         AppKitLogger::verbose("Parsing credentials: %s",$this->view["credentials"]);
 
         foreach(array("host", "service") as $affects) {
@@ -308,7 +371,7 @@ class API_Views_ApiDQLViewModel extends IcingaBaseModel {
                     break;
                 case 'groupby':
                     $query->addGroupBy($arg);
-                    break;   
+                    break;
             }
             AppKitLogger::verbose("After call query->%s(%s): %s ", $call["type"], $arg,$query->getSqlQuery());
         }
@@ -331,7 +394,7 @@ class API_Views_ApiDQLViewModel extends IcingaBaseModel {
         $keyTargetArray = array();
 
         foreach($targetValues as $target) {
-            
+
             $valueArray[] =  "'".$target["tv_val"]."'";
             $targetArray[] =  "'".$target["tv_key"]-"'";
             $dql = preg_replace('/\${credential_key_x}/',"'".$target["tv_key"]-"'",$dql,1);
@@ -344,7 +407,7 @@ class API_Views_ApiDQLViewModel extends IcingaBaseModel {
 
     private function getQueryTokens($query) {
         $tokens = array();
-        
+
         preg_match_all('/\${(.+)}/',$query,$tokens);
         AppKitLogger::verbose("Replacing tokens %s ",$tokens);
         return array_unique($tokens[1]);
@@ -394,7 +457,7 @@ class API_Views_ApiDQLViewModel extends IcingaBaseModel {
 
                 continue;
             }
-            
+
             $field = $results["field"][$i];
             $view = $results["view"][$i];
             AppKitLogger::verbose(
@@ -453,4 +516,37 @@ class API_Views_ApiDQLViewModel extends IcingaBaseModel {
         $targetValue->tv_val = $this->user->user_name;
         return array($targetValue);
     }
+
+    /**
+     * Get whether the view has the custom variable resolved
+     *
+     * @param   string $cvName Name of the custom variable
+     *
+     * @return  bool
+     */
+    public function hasResolvedCustomVariable($cvName)
+    {
+        $cvName = strtolower((string) $cvName);
+        if (isset($this->resolvedCustomVariables[$cvName])) {
+            return true;
+        }
+        return false;
+    }
+
+    /**
+     * Get the select expression of a resolved custom variable
+     *
+     * @param   string $cvName  Name of the custom variable
+     *
+     * @return  string          Select expression
+     * @throws  IcingaBaseException If the custom variable is not resolved
+     */
+    public function getResolvedCustomVariable($cvName)
+    {
+        $cvName = strtolower((string) $cvName);
+        if (! isset($this->resolvedCustomVariables[$cvName])) {
+            throw new IcingaBaseException('Custom variable '. $cvName . ' not resolved');
+        }
+        return $this->resolvedCustomVariables[$cvName];
+    }
 }
