@@ -2,20 +2,20 @@
 // {{{ICINGA_LICENSE_CODE}}}
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
-// 
-// Copyright (c) 2009-2014 Icinga Developer Team.
+//
+// Copyright (c) 2009-2015 Icinga Developer Team.
 // All rights reserved.
-// 
+//
 // icinga-web is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // icinga-web is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with icinga-web.  If not, see <http://www.gnu.org/licenses/>.
 // -----------------------------------------------------------------------------
@@ -29,6 +29,11 @@
  */
 final class AppKitLogger {
 
+    /**
+     * Command audit
+     */
+    const COMMAND = 4294967296;
+
     private static $verbose = null;
 
     private function  __construct() {
@@ -89,7 +94,7 @@ final class AppKitLogger {
                 $arg = json_encode($arg);
         }
 
-        
+
         return @vsprintf($format, $argv);
     }
 
@@ -110,7 +115,7 @@ final class AppKitLogger {
             return;
 
         $msg = $caller["class"]."::".$caller["function"]."()@".(isset($caller["line"]) ? $caller["line"] : "?") ." : ".$msg ;
-        
+
         $log->log($msg,AgaviLogger::DEBUG);
     }
 
