@@ -2,20 +2,20 @@
 // {{{ICINGA_LICENSE_CODE}}}
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
-// 
+//
 // Copyright (c) 2009-2015 Icinga Developer Team.
 // All rights reserved.
-// 
+//
 // icinga-web is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // icinga-web is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with icinga-web.  If not, see <http://www.gnu.org/licenses/>.
 // -----------------------------------------------------------------------------
@@ -25,10 +25,9 @@
     Ext.onReady(function () {
         var lTitle = _("We're Icinga");
         AppKit.util.Dom.makeImage('icinga-image-home', 'icinga.icinga-logo', { alt: lTitle , style: 'width: 200px' });
-        
+
         AppKit.util.Dom.makeImage('icinga-image-bugreport', 'icinga.bugreport', { alt: lTitle });
         AppKit.util.Dom.makeImage('icinga-image-support', 'icinga.support', { alt: lTitle });
-        AppKit.util.Dom.makeImage('icinga-image-wiki', 'icinga.wiki', { alt: lTitle });
         AppKit.util.Dom.makeImage('icinga-image-docs', 'icinga.docs', { alt: lTitle });
     });
 </script>
@@ -57,9 +56,8 @@
 </p>
 
 <p style="width: 400px; margin: 0 auto;">
-    <a id="icinga-image-bugreport" href="http://www.icinga.org/faq/how-to-report-a-bug/" target="_blank"></a>
-    <a id="icinga-image-support" href="http://www.icinga.org/support/" target="_blank"></a>
+    <a id="icinga-image-bugreport" href="https://www.icinga.org/resources/faq/" target="_blank"></a>
+    <a id="icinga-image-support" href="https://www.icinga.org/support/" target="_blank"></a>
     <br />
-    <a id="icinga-image-wiki" href="http://wiki.icinga.org/" target="_blank"></a>
     <a id="icinga-image-docs" href="http://docs.icinga.org/" target="_blank"></a>
 </p>
