@@ -460,7 +460,7 @@ class Doctrine_Collection extends Doctrine_Access implements Countable, Iterator
             $relations = $this->relation['table']->getRelations();
             foreach ($relations as $relation) {
                 if ($this->relation['class'] == $relation['localTable']->getOption('name') && $relation->getLocal() == $this->relation->getForeignFieldName()) {
-                    $record->$relation['alias'] = $this->reference;
+                    $record->{$relation['alias']} = $this->reference;
                     break;
                 }
             }
@@ -1067,4 +1067,4 @@ class Doctrine_Collection extends Doctrine_Access implements Countable, Iterator
         } 
         return $dirty; 
     }
-}
\ No newline at end of file
+}
